@@ -22,7 +22,7 @@ class ArchitypeInterp(Interp):
             KW_NODE NAME (COLON NAME)* (COLON INT)? attr_block
             | KW_EDGE NAME (COLON NAME)* attr_block
             | KW_GRAPH NAME graph_block
-            | KW_WALKER NAME namespaces? walker_block;
+            | KW_ASYNC? KW_WALKER NAME namespaces? walker_block;
         """
         if jac_ast is None:  # Using defaults
             if self.kind == "node" and self.name in ["root", "generic"]:
@@ -43,6 +43,7 @@ class ArchitypeInterp(Interp):
                 )
 
         kid = self.set_cur_ast(jac_ast)
+
         self.push_scope(JacScope(parent=self, has_obj=self, action_sets=[]))
         if kid[0].name == "KW_NODE":
             item = Node(
@@ -74,6 +75,7 @@ class ArchitypeInterp(Interp):
                 name=kid[1].token_text(),
                 kind=kid[0].token_text(),
                 parent=self.parent(),
+                is_async=self.is_async,
             )
             if kid[2].name == "namespaces":
                 item.namespaces = self.run_namespaces(jac_ast.kid[2])
