@@ -1,5 +1,5 @@
 from .state import ServiceState
-from .common import CommonService, ProxyService
+from .common import CommonService, ProxyService, MetaProperties
 from .redis import RedisService
 from .task import TaskService
 from .mail import MailService
@@ -7,6 +7,7 @@ from .meta import MetaService
 
 __all__ = [
     "ServiceState",
+    "MetaProperties",
     "CommonService",
     "ProxyService",
     "RedisService",
