@@ -34,14 +34,14 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_jac_code(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog1)
         self.assertIsNotNone(sent.run_architype("get_gen_day"))
         self.assertIsNotNone(sent.arch_ids.get_obj_by_name("week", kind="node"))
 
     def test_sentinel_loading_jac_code_multiple_times(self):
         """Test registering resets correctly for multiple attempts"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog0)
         num_arch = len(sent.arch_ids)
         sent.register_code(jtc.prog0)
@@ -51,7 +51,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_register_dep_on_static_errors(self):
         """Test Jac registering is dependant on correct static/dynamic code"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         correct = "node b { has anchor a; }"
         wrong1 = "adfdsf"
         sent.register_code(correct)
@@ -67,7 +67,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_arhitype(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog1)
         self.assertGreater(
             len(sent.arch_ids.get_obj_by_name("month", kind="node").code_ir), 5
@@ -75,7 +75,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_running_basic_walker(self):
         """Test the execution of a basic walker building graph"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.run_architype("get_gen_day")
@@ -91,7 +91,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_setp_running_walker(self):
         """Test the execution of a basic walker building graph"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.run_architype("get_gen_day")
@@ -114,7 +114,7 @@ class JacTests(TestCaseHelper, TestCase):
         """
         Test that  no loss or gain of data on second trak on second trek
         """
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
@@ -137,7 +137,7 @@ class JacTests(TestCaseHelper, TestCase):
         scalably (node contexts dont get deleted when arch_ids deleted)
         """
         lact.load_local_actions(os.path.dirname(__file__) + "/infer.py")
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.run_architype("get_gen_day")
@@ -154,7 +154,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sent_loads_complex_walker_and_arch(self):
         """Test loading attributes of arch and walkers"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("testnode", kind="node").run()
         test_walker = sent.run_architype("testwalk")
@@ -164,11 +164,11 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_availabilty_of_global_functions(self):
         """Test preset function loading"""
-        self.assertGreater(len(self.meta.hook().global_action_list), 10)
+        self.assertGreater(len(self.meta.build_hook().global_action_list), 10)
 
     def test_multiple_edged_between_nodes_work(self):
         """Test that multiple edges between the same two nodes are allowed"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey)
         test_walker = sent.run_architype("init")
@@ -183,7 +183,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all(self):
         """Test that multiple edges deleted correctly if delete all"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey2)
         test_walker = sent.run_architype("init")
@@ -194,7 +194,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_specific(self):
         """Test that multiple edges deleted correctly if delete all"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey2b)
         test_walker = sent.run_architype("init")
@@ -205,7 +205,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_labeled(self):
         """Test that multiple edges deleted correctly if delete all"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey2c)
         test_walker = sent.run_architype("init")
@@ -216,7 +216,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_filtered(self):
         """Test that multiple edges deleted correctly if delete filtered"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey3)
         test_walker = sent.run_architype("init")
@@ -227,7 +227,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_generic_can_be_used_to_specify_generic_edges(self):
         """Test that generic edge tag works"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey4)
         test_walker = sent.run_architype("init")
@@ -238,7 +238,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_simultaneously(self):
         """Test disconnecting mutilpe nodes"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey5)
         test_walker = sent.run_architype("init")
@@ -249,7 +249,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_can_connect_multi_nodes_simultaneously(self):
         """Test connecting mutilpe nodes"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey6)
         test_walker = sent.run_architype("init")
@@ -260,7 +260,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_advanced(self):
         """Test disconnecting mutilpe nodes advanced"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edgey7)
         test_walker = sent.run_architype("init")
@@ -271,7 +271,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_accessing_edges_basic(self):
         """Test accessing Edges"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edge_access)
         test_walker = sent.run_architype("init")
@@ -287,7 +287,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_has_assign(self):
         """Test assignment on definition"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.has_assign)
         test_walker = sent.run_architype("init")
@@ -304,7 +304,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_global_get_set(self):
         """Test assignment on definition"""
-        mast = self.meta.super_master()
+        mast = self.meta.build_super_master()
         sent = Sentinel(m_id=mast.jid, h=mast._h)
         gph = Graph(m_id=mast.jid, h=mast._h)
         sent.register_code(jtc.set_get_global)
@@ -318,7 +318,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_global_set_requires_admin(self):
         """Test assignment on definition"""
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         sent = Sentinel(m_id=mast.jid, h=mast._h)
         gph = Graph(m_id=mast.jid, h=mast._h)
         sent.register_code(jtc.set_get_global2)
@@ -332,14 +332,14 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_sentinel_version_label(self):
         """Test sentinel version labeling"""
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         sent = Sentinel(m_id=mast.jid, h=mast._h)
         sent.register_code(jtc.version_label)
         self.assertEqual(sent.version, "alpha-1.0")
 
     def test_visibility_builtins(self):
         """Test builtins to see into nodes and edges"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.visibility_builtins)
         test_walker = sent.run_architype("init")
@@ -352,7 +352,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_spawn_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.spawn_ctx_edge_node)
         test_walker = sent.run_architype("init")
@@ -365,7 +365,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_filter_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.filter_ctx_edge_node)
         test_walker = sent.run_architype("init")
@@ -375,7 +375,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.report[1]), 0)
 
     def test_null_handling(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.null_handleing)
         test_walker = sent.run_architype("init")
@@ -387,7 +387,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[3], False)
 
     def test_bool_type_convert(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.bool_type_convert)
         test_walker = sent.run_architype("init")
@@ -397,7 +397,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(True, test_walker.report[1]["name"])
 
     def test_typecasts(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.typecasts)
         test_walker = sent.run_architype("init")
@@ -411,7 +411,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[5], "Types comes back correct")
 
     def test_typecast_error(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.typecasts_error)
         test_walker = sent.run_architype("init")
@@ -424,7 +424,7 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_filter_on_context(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.filter_on_context)
         test_walker = sent.run_architype("init")
@@ -435,7 +435,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("name", test_walker.report[0][2].keys())
 
     def test_string_manipulation(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.string_manipulation)
         test_walker = sent.run_architype("init")
@@ -474,7 +474,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[29], True)
 
     def test_list_manipulation(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.list_manipulation)
         test_walker = sent.run_architype("init")
@@ -494,7 +494,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[10], [])
 
     def test_list_reversed(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.list_reversed)
         test_walker = sent.run_architype("init")
@@ -505,7 +505,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[1], [4, 2, 7])
 
     def test_dict_manipulation(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.dict_manipulation)
         test_walker = sent.run_architype("init")
@@ -522,7 +522,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[7], {})
 
     def test_string_join(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.string_join)
         test_walker = sent.run_architype("init")
@@ -532,7 +532,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0], "test_me_now")
 
     def test_sub_list(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.sub_list)
         test_walker = sent.run_architype("init")
@@ -544,7 +544,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0][2], 7)
 
     def test_destroy_and_misc(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.destroy_and_misc)
         test_walker = sent.run_architype("init")
@@ -569,7 +569,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[9], True)
 
     def test_arbitrary_assign_on_element(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.arbitrary_assign_on_element)
         test_walker = sent.run_architype("init")
@@ -581,7 +581,7 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_try_else_stmts(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.try_else_stmts)
         test_walker = sent.run_architype("init")
@@ -606,7 +606,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep[3], 2)
 
     def test_node_edge_same_name(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.node_edge_same_name)
         test_walker = sent.run_architype("init")
@@ -619,7 +619,7 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_testcases(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.testcases)
         sent.run_tests(silent=True)
         self.assertEqual(len(sent.testcases), 4)
@@ -627,7 +627,7 @@ class JacTests(TestCaseHelper, TestCase):
             self.assertEqual(i["passed"], True)
 
     def test_testcase_asserts(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         sent.register_code(jtc.testcase_asserts)
         sent.run_tests(silent=True)
         self.assertEqual(len(sent.testcases), 3)
@@ -636,7 +636,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(sent.testcases[2]["passed"], False)
 
     def test_report_not_to_jacset(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.report_not_to_jacset)
         test_walker = sent.run_architype("init")
@@ -647,7 +647,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("j_type", rep[0][0].keys())
 
     def test_walker_spawn_unwrap_check(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.walker_spawn_unwrap_check)
         test_walker = sent.run_architype("init")
@@ -657,7 +657,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertTrue(rep[0].startswith("urn:uuid"))
 
     def test_std_get_report(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.std_get_report)
         test_walker = sent.run_architype("init")
@@ -667,7 +667,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep, [3, 5, 6, 7, [3, 5, 6, 7], 8])
 
     def test_func_with_array_index(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.func_with_array_index)
         test_walker = sent.run_architype("init")
@@ -677,7 +677,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(rep, [3, 5, 3])
 
     def test_rt_error_test1(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.rt_error_test1)
         test_walker = sent.run_architype("init")
@@ -688,7 +688,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn(" col ", test_walker.runtime_errors[0])
 
     def test_root_type_nodes(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.root_type_nodes)
         test_walker = sent.run_architype("init")
@@ -698,7 +698,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, ["root", "root"])
 
     def test_invalid_key_error(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.invalid_key_error)
         test_walker = sent.run_architype("init")
@@ -708,7 +708,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertGreater(len(errors), 0)
 
     def test_auto_cast(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.auto_cast)
         test_walker = sent.run_architype("init")
@@ -718,7 +718,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, [True, True])
 
     def test_no_error_on_dict_key_assign(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.no_error_on_dict_key_assign)
         test_walker = sent.run_architype("init")
@@ -729,7 +729,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.runtime_errors), 0)
 
     def test_report_status(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.report_status)
         test_walker = sent.run_architype("init")
@@ -740,7 +740,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report_status, 302)
 
     def test_graph_in_graph(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.graph_in_graph)
         test_walker = sent.run_architype("init")
@@ -750,7 +750,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(len(report), 3)
 
     def test_min_max_on_list(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.min_max_on_list)
         test_walker = sent.run_architype("init")
@@ -760,7 +760,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, [531.1, 3, 5, 1])
 
     def test_edge_bug(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.edge_bug)
         test_walker = sent.run_architype("init")
@@ -770,7 +770,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(len(report[0]), 4)
 
     def test_rand_choice(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtc.rand_choice)
         test_walker = sent.run_architype("init")
